==> zio-aws-sagemaker_2.12-5.17.104.13-sources.jar: zio/aws/sagemaker/model/CreateCompilationJobRequest.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.sagemaker.model.primitives.{ModelPackageArn, RoleArn, EntityName}
import scala.jdk.CollectionConverters._
final case class CreateCompilationJobRequest(
    compilationJobName: EntityName,
    roleArn: RoleArn,
    modelPackageVersionArn: Option[ModelPackageArn] = None,
    inputConfig: Option[zio.aws.sagemaker.model.InputConfig] = None,
    outputConfig: zio.aws.sagemaker.model.OutputConfig,
    vpcConfig: Option[zio.aws.sagemaker.model.NeoVpcConfig] = None,
    stoppingCondition: zio.aws.sagemaker.model.StoppingCondition,
    tags: Option[Iterable[zio.aws.sagemaker.model.Tag]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.CreateCompilationJobRequest = {
    import CreateCompilationJobRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.CreateCompilationJobRequest
      .builder()
      .compilationJobName(
        EntityName.unwrap(compilationJobName): java.lang.String
      )
      .roleArn(RoleArn.unwrap(roleArn): java.lang.String)
      .optionallyWith(
        modelPackageVersionArn.map(value =>
          ModelPackageArn.unwrap(value): java.lang.String
        )
      )(_.modelPackageVersionArn)
      .optionallyWith(inputConfig.map(value => value.buildAwsValue()))(
        _.inputConfig
      )
      .outputConfig(outputConfig.buildAwsValue())
      .optionallyWith(vpcConfig.map(value => value.buildAwsValue()))(
        _.vpcConfig
      )
      .stoppingCondition(stoppingCondition.buildAwsValue())
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.CreateCompilationJobRequest.ReadOnly =
    zio.aws.sagemaker.model.CreateCompilationJobRequest.wrap(buildAwsValue())
}
object CreateCompilationJobRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.CreateCompilationJobRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.CreateCompilationJobRequest =
      zio.aws.sagemaker.model.CreateCompilationJobRequest(
        compilationJobName,
        roleArn,
        modelPackageVersionArn.map(value => value),
        inputConfig.map(value => value.asEditable),
        outputConfig.asEditable,
        vpcConfig.map(value => value.asEditable),
        stoppingCondition.asEditable,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def compilationJobName: EntityName
    def roleArn: RoleArn
    def modelPackageVersionArn: Option[ModelPackageArn]
    def inputConfig: Option[zio.aws.sagemaker.model.InputConfig.ReadOnly]
    def outputConfig: zio.aws.sagemaker.model.OutputConfig.ReadOnly
    def vpcConfig: Option[zio.aws.sagemaker.model.NeoVpcConfig.ReadOnly]
    def stoppingCondition: zio.aws.sagemaker.model.StoppingCondition.ReadOnly
    def tags: Option[List[zio.aws.sagemaker.model.Tag.ReadOnly]]
    def getCompilationJobName: ZIO[Any, Nothing, EntityName] =
      ZIO.succeed(compilationJobName)
    def getRoleArn: ZIO[Any, Nothing, RoleArn] = ZIO.succeed(roleArn)
    def getModelPackageVersionArn: ZIO[Any, AwsError, ModelPackageArn] =
      AwsError.unwrapOptionField(
        "modelPackageVersionArn",
        modelPackageVersionArn
      )
    def getInputConfig
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.InputConfig.ReadOnly] =
      AwsError.unwrapOptionField("inputConfig", inputConfig)
    def getOutputConfig
        : ZIO[Any, Nothing, zio.aws.sagemaker.model.OutputConfig.ReadOnly] =
      ZIO.succeed(outputConfig)
    def getVpcConfig
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.NeoVpcConfig.ReadOnly] =
      AwsError.unwrapOptionField("vpcConfig", vpcConfig)
    def getStoppingCondition: ZIO[
      Any,
      Nothing,
      zio.aws.sagemaker.model.StoppingCondition.ReadOnly
    ] = ZIO.succeed(stoppingCondition)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.sagemaker.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.CreateCompilationJobRequest
  ) extends zio.aws.sagemaker.model.CreateCompilationJobRequest.ReadOnly {
    override val compilationJobName: EntityName =
      zio.aws.sagemaker.model.primitives.EntityName(impl.compilationJobName())
    override val roleArn: RoleArn =
      zio.aws.sagemaker.model.primitives.RoleArn(impl.roleArn())
    override val modelPackageVersionArn: Option[ModelPackageArn] = scala
      .Option(impl.modelPackageVersionArn())
      .map(value => zio.aws.sagemaker.model.primitives.ModelPackageArn(value))
    override val inputConfig
        : Option[zio.aws.sagemaker.model.InputConfig.ReadOnly] = scala
      .Option(impl.inputConfig())
      .map(value => zio.aws.sagemaker.model.InputConfig.wrap(value))
    override val outputConfig: zio.aws.sagemaker.model.OutputConfig.ReadOnly =
      zio.aws.sagemaker.model.OutputConfig.wrap(impl.outputConfig())
    override val vpcConfig
        : Option[zio.aws.sagemaker.model.NeoVpcConfig.ReadOnly] = scala
      .Option(impl.vpcConfig())
      .map(value => zio.aws.sagemaker.model.NeoVpcConfig.wrap(value))
    override val stoppingCondition
        : zio.aws.sagemaker.model.StoppingCondition.ReadOnly =
      zio.aws.sagemaker.model.StoppingCondition.wrap(impl.stoppingCondition())
    override val tags: Option[List[zio.aws.sagemaker.model.Tag.ReadOnly]] =
      scala
        .Option(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sagemaker.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.CreateCompilationJobRequest
  ): zio.aws.sagemaker.model.CreateCompilationJobRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-sagemaker_2.12-5.20.7.3-sources.jar: zio/aws/sagemaker/model/CreateCompilationJobRequest.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.{ModelPackageArn, RoleArn, EntityName}
import scala.jdk.CollectionConverters._
final case class CreateCompilationJobRequest(
    compilationJobName: EntityName,
    roleArn: RoleArn,
    modelPackageVersionArn: Optional[ModelPackageArn] = Optional.Absent,
    inputConfig: Optional[zio.aws.sagemaker.model.InputConfig] =
      Optional.Absent,
    outputConfig: zio.aws.sagemaker.model.OutputConfig,
    vpcConfig: Optional[zio.aws.sagemaker.model.NeoVpcConfig] = Optional.Absent,
    stoppingCondition: zio.aws.sagemaker.model.StoppingCondition,
    tags: Optional[Iterable[zio.aws.sagemaker.model.Tag]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.CreateCompilationJobRequest = {
    import CreateCompilationJobRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.CreateCompilationJobRequest
      .builder()
      .compilationJobName(
        EntityName.unwrap(compilationJobName): java.lang.String
      )
      .roleArn(RoleArn.unwrap(roleArn): java.lang.String)
      .optionallyWith(
        modelPackageVersionArn.map(value =>
          ModelPackageArn.unwrap(value): java.lang.String
        )
      )(_.modelPackageVersionArn)
      .optionallyWith(inputConfig.map(value => value.buildAwsValue()))(
        _.inputConfig
      )
      .outputConfig(outputConfig.buildAwsValue())
      .optionallyWith(vpcConfig.map(value => value.buildAwsValue()))(
        _.vpcConfig
      )
      .stoppingCondition(stoppingCondition.buildAwsValue())
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.CreateCompilationJobRequest.ReadOnly =
    zio.aws.sagemaker.model.CreateCompilationJobRequest.wrap(buildAwsValue())
}
object CreateCompilationJobRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.CreateCompilationJobRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.CreateCompilationJobRequest =
      zio.aws.sagemaker.model.CreateCompilationJobRequest(
        compilationJobName,
        roleArn,
        modelPackageVersionArn.map(value => value),
        inputConfig.map(value => value.asEditable),
        outputConfig.asEditable,
        vpcConfig.map(value => value.asEditable),
        stoppingCondition.asEditable,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def compilationJobName: EntityName
    def roleArn: RoleArn
    def modelPackageVersionArn: Optional[ModelPackageArn]
    def inputConfig: Optional[zio.aws.sagemaker.model.InputConfig.ReadOnly]
    def outputConfig: zio.aws.sagemaker.model.OutputConfig.ReadOnly
    def vpcConfig: Optional[zio.aws.sagemaker.model.NeoVpcConfig.ReadOnly]
    def stoppingCondition: zio.aws.sagemaker.model.StoppingCondition.ReadOnly
    def tags: Optional[List[zio.aws.sagemaker.model.Tag.ReadOnly]]
    def getCompilationJobName: ZIO[Any, Nothing, EntityName] =
      ZIO.succeed(compilationJobName)
    def getRoleArn: ZIO[Any, Nothing, RoleArn] = ZIO.succeed(roleArn)
    def getModelPackageVersionArn: ZIO[Any, AwsError, ModelPackageArn] =
      AwsError.unwrapOptionField(
        "modelPackageVersionArn",
        modelPackageVersionArn
      )
    def getInputConfig
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.InputConfig.ReadOnly] =
      AwsError.unwrapOptionField("inputConfig", inputConfig)
    def getOutputConfig
        : ZIO[Any, Nothing, zio.aws.sagemaker.model.OutputConfig.ReadOnly] =
      ZIO.succeed(outputConfig)
    def getVpcConfig
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.NeoVpcConfig.ReadOnly] =
      AwsError.unwrapOptionField("vpcConfig", vpcConfig)
    def getStoppingCondition: ZIO[
      Any,
      Nothing,
      zio.aws.sagemaker.model.StoppingCondition.ReadOnly
    ] = ZIO.succeed(stoppingCondition)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.sagemaker.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.CreateCompilationJobRequest
  ) extends zio.aws.sagemaker.model.CreateCompilationJobRequest.ReadOnly {
    override val compilationJobName: EntityName =
      zio.aws.sagemaker.model.primitives.EntityName(impl.compilationJobName())
    override val roleArn: RoleArn =
      zio.aws.sagemaker.model.primitives.RoleArn(impl.roleArn())
    override val modelPackageVersionArn: Optional[ModelPackageArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.modelPackageVersionArn())
        .map(value => zio.aws.sagemaker.model.primitives.ModelPackageArn(value))
    override val inputConfig
        : Optional[zio.aws.sagemaker.model.InputConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.inputConfig())
        .map(value => zio.aws.sagemaker.model.InputConfig.wrap(value))
    override val outputConfig: zio.aws.sagemaker.model.OutputConfig.ReadOnly =
      zio.aws.sagemaker.model.OutputConfig.wrap(impl.outputConfig())
    override val vpcConfig
        : Optional[zio.aws.sagemaker.model.NeoVpcConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.vpcConfig())
        .map(value => zio.aws.sagemaker.model.NeoVpcConfig.wrap(value))
    override val stoppingCondition
        : zio.aws.sagemaker.model.StoppingCondition.ReadOnly =
      zio.aws.sagemaker.model.StoppingCondition.wrap(impl.stoppingCondition())
    override val tags: Optional[List[zio.aws.sagemaker.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sagemaker.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.CreateCompilationJobRequest
  ): zio.aws.sagemaker.model.CreateCompilationJobRequest.ReadOnly = new Wrapper(
    impl
  )
}
